"""AbstractAssemblyCompoundPowerFlow"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.power_flows.compound import _4246
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ABSTRACT_ASSEMBLY_COMPOUND_POWER_FLOW = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows.Compound",
    "AbstractAssemblyCompoundPowerFlow",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.power_flows import _4032
    from mastapy.system_model.analyses_and_results.power_flows.compound import (
        _4173,
        _4174,
        _4177,
        _4180,
        _4185,
        _4187,
        _4188,
        _4193,
        _4198,
        _4201,
        _4204,
        _4208,
        _4210,
        _4216,
        _4222,
        _4224,
        _4227,
        _4231,
        _4235,
        _4238,
        _4241,
        _4247,
        _4251,
        _4258,
        _4261,
        _4265,
        _4268,
        _4269,
        _4274,
        _4277,
        _4280,
        _4284,
        _4292,
        _4295,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("AbstractAssemblyCompoundPowerFlow",)


Self = TypeVar("Self", bound="AbstractAssemblyCompoundPowerFlow")


class AbstractAssemblyCompoundPowerFlow(_4246.PartCompoundPowerFlow):
    """AbstractAssemblyCompoundPowerFlow

    This is a mastapy class.
    """

    TYPE = _ABSTRACT_ASSEMBLY_COMPOUND_POWER_FLOW
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_AbstractAssemblyCompoundPowerFlow")

    class _Cast_AbstractAssemblyCompoundPowerFlow:
        """Special nested class for casting AbstractAssemblyCompoundPowerFlow to subclasses."""

        def __init__(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
            parent: "AbstractAssemblyCompoundPowerFlow",
        ):
            self._parent = parent

        @property
        def part_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4246.PartCompoundPowerFlow":
            return self._parent._cast(_4246.PartCompoundPowerFlow)

        @property
        def part_compound_analysis(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def agma_gleason_conical_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4173.AGMAGleasonConicalGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4173,
            )

            return self._parent._cast(_4173.AGMAGleasonConicalGearSetCompoundPowerFlow)

        @property
        def assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4174.AssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4174,
            )

            return self._parent._cast(_4174.AssemblyCompoundPowerFlow)

        @property
        def belt_drive_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4177.BeltDriveCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4177,
            )

            return self._parent._cast(_4177.BeltDriveCompoundPowerFlow)

        @property
        def bevel_differential_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4180.BevelDifferentialGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4180,
            )

            return self._parent._cast(_4180.BevelDifferentialGearSetCompoundPowerFlow)

        @property
        def bevel_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4185.BevelGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4185,
            )

            return self._parent._cast(_4185.BevelGearSetCompoundPowerFlow)

        @property
        def bolted_joint_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4187.BoltedJointCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4187,
            )

            return self._parent._cast(_4187.BoltedJointCompoundPowerFlow)

        @property
        def clutch_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4188.ClutchCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4188,
            )

            return self._parent._cast(_4188.ClutchCompoundPowerFlow)

        @property
        def concept_coupling_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4193.ConceptCouplingCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4193,
            )

            return self._parent._cast(_4193.ConceptCouplingCompoundPowerFlow)

        @property
        def concept_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4198.ConceptGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4198,
            )

            return self._parent._cast(_4198.ConceptGearSetCompoundPowerFlow)

        @property
        def conical_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4201.ConicalGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4201,
            )

            return self._parent._cast(_4201.ConicalGearSetCompoundPowerFlow)

        @property
        def coupling_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4204.CouplingCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4204,
            )

            return self._parent._cast(_4204.CouplingCompoundPowerFlow)

        @property
        def cvt_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4208.CVTCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4208,
            )

            return self._parent._cast(_4208.CVTCompoundPowerFlow)

        @property
        def cycloidal_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4210.CycloidalAssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4210,
            )

            return self._parent._cast(_4210.CycloidalAssemblyCompoundPowerFlow)

        @property
        def cylindrical_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4216.CylindricalGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4216,
            )

            return self._parent._cast(_4216.CylindricalGearSetCompoundPowerFlow)

        @property
        def face_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4222.FaceGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4222,
            )

            return self._parent._cast(_4222.FaceGearSetCompoundPowerFlow)

        @property
        def flexible_pin_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4224.FlexiblePinAssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4224,
            )

            return self._parent._cast(_4224.FlexiblePinAssemblyCompoundPowerFlow)

        @property
        def gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4227.GearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4227,
            )

            return self._parent._cast(_4227.GearSetCompoundPowerFlow)

        @property
        def hypoid_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4231.HypoidGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4231,
            )

            return self._parent._cast(_4231.HypoidGearSetCompoundPowerFlow)

        @property
        def klingelnberg_cyclo_palloid_conical_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4235.KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4235,
            )

            return self._parent._cast(
                _4235.KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4238.KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4238,
            )

            return self._parent._cast(
                _4238.KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4241.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4241,
            )

            return self._parent._cast(
                _4241.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow
            )

        @property
        def part_to_part_shear_coupling_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4247.PartToPartShearCouplingCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4247,
            )

            return self._parent._cast(_4247.PartToPartShearCouplingCompoundPowerFlow)

        @property
        def planetary_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4251.PlanetaryGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4251,
            )

            return self._parent._cast(_4251.PlanetaryGearSetCompoundPowerFlow)

        @property
        def rolling_ring_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4258.RollingRingAssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4258,
            )

            return self._parent._cast(_4258.RollingRingAssemblyCompoundPowerFlow)

        @property
        def root_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4261.RootAssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4261,
            )

            return self._parent._cast(_4261.RootAssemblyCompoundPowerFlow)

        @property
        def specialised_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4265.SpecialisedAssemblyCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4265,
            )

            return self._parent._cast(_4265.SpecialisedAssemblyCompoundPowerFlow)

        @property
        def spiral_bevel_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4268.SpiralBevelGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4268,
            )

            return self._parent._cast(_4268.SpiralBevelGearSetCompoundPowerFlow)

        @property
        def spring_damper_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4269.SpringDamperCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4269,
            )

            return self._parent._cast(_4269.SpringDamperCompoundPowerFlow)

        @property
        def straight_bevel_diff_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4274.StraightBevelDiffGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4274,
            )

            return self._parent._cast(_4274.StraightBevelDiffGearSetCompoundPowerFlow)

        @property
        def straight_bevel_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4277.StraightBevelGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4277,
            )

            return self._parent._cast(_4277.StraightBevelGearSetCompoundPowerFlow)

        @property
        def synchroniser_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4280.SynchroniserCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4280,
            )

            return self._parent._cast(_4280.SynchroniserCompoundPowerFlow)

        @property
        def torque_converter_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4284.TorqueConverterCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4284,
            )

            return self._parent._cast(_4284.TorqueConverterCompoundPowerFlow)

        @property
        def worm_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4292.WormGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4292,
            )

            return self._parent._cast(_4292.WormGearSetCompoundPowerFlow)

        @property
        def zerol_bevel_gear_set_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "_4295.ZerolBevelGearSetCompoundPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows.compound import (
                _4295,
            )

            return self._parent._cast(_4295.ZerolBevelGearSetCompoundPowerFlow)

        @property
        def abstract_assembly_compound_power_flow(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
        ) -> "AbstractAssemblyCompoundPowerFlow":
            return self._parent

        def __getattr__(
            self: "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "AbstractAssemblyCompoundPowerFlow.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_analysis_cases(self: Self) -> "List[_4032.AbstractAssemblyPowerFlow]":
        """List[mastapy.system_model.analyses_and_results.power_flows.AbstractAssemblyPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases_ready(
        self: Self,
    ) -> "List[_4032.AbstractAssemblyPowerFlow]":
        """List[mastapy.system_model.analyses_and_results.power_flows.AbstractAssemblyPowerFlow]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "AbstractAssemblyCompoundPowerFlow._Cast_AbstractAssemblyCompoundPowerFlow":
        return self._Cast_AbstractAssemblyCompoundPowerFlow(self)



"""FEPart"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor
from mastapy._internal.implicit import list_with_selected_item
from mastapy.system_model.fe import _2383
from mastapy._internal.python_net import python_net_import
from mastapy.system_model.part_model import _2436
from mastapy._internal.cast_exception import CastException

_STRING = python_net_import("System", "String")
_FE_PART = python_net_import("SMT.MastaAPI.SystemModel.PartModel", "FEPart")

if TYPE_CHECKING:
    from mastapy.math_utility import _1498
    from mastapy.system_model.part_model import _2444, _2468
    from mastapy.system_model import _2203


__docformat__ = "restructuredtext en"
__all__ = ("FEPart",)


Self = TypeVar("Self", bound="FEPart")


class FEPart(_2436.AbstractShaftOrHousing):
    """FEPart

    This is a mastapy class.
    """

    TYPE = _FE_PART
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_FEPart")

    class _Cast_FEPart:
        """Special nested class for casting FEPart to subclasses."""

        def __init__(self: "FEPart._Cast_FEPart", parent: "FEPart"):
            self._parent = parent

        @property
        def abstract_shaft_or_housing(
            self: "FEPart._Cast_FEPart",
        ) -> "_2436.AbstractShaftOrHousing":
            return self._parent._cast(_2436.AbstractShaftOrHousing)

        @property
        def component(self: "FEPart._Cast_FEPart") -> "_2444.Component":
            from mastapy.system_model.part_model import _2444

            return self._parent._cast(_2444.Component)

        @property
        def part(self: "FEPart._Cast_FEPart") -> "_2468.Part":
            from mastapy.system_model.part_model import _2468

            return self._parent._cast(_2468.Part)

        @property
        def design_entity(self: "FEPart._Cast_FEPart") -> "_2203.DesignEntity":
            from mastapy.system_model import _2203

            return self._parent._cast(_2203.DesignEntity)

        @property
        def fe_part(self: "FEPart._Cast_FEPart") -> "FEPart":
            return self._parent

        def __getattr__(self: "FEPart._Cast_FEPart", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "FEPart.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def three_d_node_size(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ThreeDNodeSize

        if temp is None:
            return 0.0

        return temp

    @three_d_node_size.setter
    @enforce_parameter_types
    def three_d_node_size(self: Self, value: "float"):
        self.wrapped.ThreeDNodeSize = float(value) if value is not None else 0.0

    @property
    def default_fe_substructure(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_FESubstructure":
        """ListWithSelectedItem[mastapy.system_model.fe.FESubstructure]"""
        temp = self.wrapped.DefaultFESubstructure

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_FESubstructure",
        )(temp)

    @default_fe_substructure.setter
    @enforce_parameter_types
    def default_fe_substructure(self: Self, value: "_2383.FESubstructure"):
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_FESubstructure.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_FESubstructure.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.DefaultFESubstructure = value

    @property
    def knows_scalar_mass(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KnowsScalarMass

        if temp is None:
            return False

        return temp

    @property
    def local_coordinate_system(self: Self) -> "_1498.CoordinateSystem3D":
        """mastapy.math_utility.CoordinateSystem3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LocalCoordinateSystem

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    def create_fe_substructure(self: Self) -> "_2383.FESubstructure":
        """mastapy.system_model.fe.FESubstructure"""
        method_result = self.wrapped.CreateFESubstructure()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def create_fe_substructure_with_name(
        self: Self, name: "str"
    ) -> "_2383.FESubstructure":
        """mastapy.system_model.fe.FESubstructure

        Args:
            name (str)
        """
        name = str(name)
        method_result = self.wrapped.CreateFESubstructure.Overloads[_STRING](
            name if name else ""
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def remove_fe_substructure(
        self: Self, fe_substructure: "_2383.FESubstructure"
    ) -> "bool":
        """bool

        Args:
            fe_substructure (mastapy.system_model.fe.FESubstructure)
        """
        method_result = self.wrapped.RemoveFESubstructure(
            fe_substructure.wrapped if fe_substructure else None
        )
        return method_result

    @enforce_parameter_types
    def select_fe_substructure(self: Self, fe_substructure: "_2383.FESubstructure"):
        """Method does not return.

        Args:
            fe_substructure (mastapy.system_model.fe.FESubstructure)
        """
        self.wrapped.SelectFESubstructure(
            fe_substructure.wrapped if fe_substructure else None
        )

    @property
    def cast_to(self: Self) -> "FEPart._Cast_FEPart":
        return self._Cast_FEPart(self)



"""HarmonicAnalysisOfSingleExcitation"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.analysis_cases import _7550
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation",
    "HarmonicAnalysisOfSingleExcitation",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.harmonic_analyses import _5679
    from mastapy.system_model.analyses_and_results.analysis_cases import _7535
    from mastapy.system_model.analyses_and_results import _2650


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicAnalysisOfSingleExcitation",)


Self = TypeVar("Self", bound="HarmonicAnalysisOfSingleExcitation")


class HarmonicAnalysisOfSingleExcitation(_7550.StaticLoadAnalysisCase):
    """HarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE = _HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HarmonicAnalysisOfSingleExcitation")

    class _Cast_HarmonicAnalysisOfSingleExcitation:
        """Special nested class for casting HarmonicAnalysisOfSingleExcitation to subclasses."""

        def __init__(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
            parent: "HarmonicAnalysisOfSingleExcitation",
        ):
            self._parent = parent

        @property
        def static_load_analysis_case(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
        ) -> "_7550.StaticLoadAnalysisCase":
            return self._parent._cast(_7550.StaticLoadAnalysisCase)

        @property
        def analysis_case(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
        ) -> "_7535.AnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7535

            return self._parent._cast(_7535.AnalysisCase)

        @property
        def context(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
        ) -> "_2650.Context":
            from mastapy.system_model.analyses_and_results import _2650

            return self._parent._cast(_2650.Context)

        @property
        def harmonic_analysis_of_single_excitation(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
        ) -> "HarmonicAnalysisOfSingleExcitation":
            return self._parent

        def __getattr__(
            self: "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "HarmonicAnalysisOfSingleExcitation.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def excitation_detail(self: Self) -> "_5679.AbstractPeriodicExcitationDetail":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.AbstractPeriodicExcitationDetail

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ExcitationDetail

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "HarmonicAnalysisOfSingleExcitation._Cast_HarmonicAnalysisOfSingleExcitation":
        return self._Cast_HarmonicAnalysisOfSingleExcitation(self)



"""ConicalGear"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.system_model.part_model.gears import _2530
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Gears", "ConicalGear"
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.gears import (
        _2531,
        _2513,
        _2515,
        _2517,
        _2518,
        _2519,
        _2534,
        _2536,
        _2538,
        _2540,
        _2543,
        _2545,
        _2547,
        _2549,
        _2550,
        _2553,
    )
    from mastapy.gears.gear_designs.conical import _1154
    from mastapy.system_model.part_model import _2464, _2444, _2468
    from mastapy.system_model import _2203


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGear",)


Self = TypeVar("Self", bound="ConicalGear")


class ConicalGear(_2530.Gear):
    """ConicalGear

    This is a mastapy class.
    """

    TYPE = _CONICAL_GEAR
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ConicalGear")

    class _Cast_ConicalGear:
        """Special nested class for casting ConicalGear to subclasses."""

        def __init__(self: "ConicalGear._Cast_ConicalGear", parent: "ConicalGear"):
            self._parent = parent

        @property
        def gear(self: "ConicalGear._Cast_ConicalGear") -> "_2530.Gear":
            return self._parent._cast(_2530.Gear)

        @property
        def mountable_component(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2464.MountableComponent":
            from mastapy.system_model.part_model import _2464

            return self._parent._cast(_2464.MountableComponent)

        @property
        def component(self: "ConicalGear._Cast_ConicalGear") -> "_2444.Component":
            from mastapy.system_model.part_model import _2444

            return self._parent._cast(_2444.Component)

        @property
        def part(self: "ConicalGear._Cast_ConicalGear") -> "_2468.Part":
            from mastapy.system_model.part_model import _2468

            return self._parent._cast(_2468.Part)

        @property
        def design_entity(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2203.DesignEntity":
            from mastapy.system_model import _2203

            return self._parent._cast(_2203.DesignEntity)

        @property
        def agma_gleason_conical_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2513.AGMAGleasonConicalGear":
            from mastapy.system_model.part_model.gears import _2513

            return self._parent._cast(_2513.AGMAGleasonConicalGear)

        @property
        def bevel_differential_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2515.BevelDifferentialGear":
            from mastapy.system_model.part_model.gears import _2515

            return self._parent._cast(_2515.BevelDifferentialGear)

        @property
        def bevel_differential_planet_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2517.BevelDifferentialPlanetGear":
            from mastapy.system_model.part_model.gears import _2517

            return self._parent._cast(_2517.BevelDifferentialPlanetGear)

        @property
        def bevel_differential_sun_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2518.BevelDifferentialSunGear":
            from mastapy.system_model.part_model.gears import _2518

            return self._parent._cast(_2518.BevelDifferentialSunGear)

        @property
        def bevel_gear(self: "ConicalGear._Cast_ConicalGear") -> "_2519.BevelGear":
            from mastapy.system_model.part_model.gears import _2519

            return self._parent._cast(_2519.BevelGear)

        @property
        def hypoid_gear(self: "ConicalGear._Cast_ConicalGear") -> "_2534.HypoidGear":
            from mastapy.system_model.part_model.gears import _2534

            return self._parent._cast(_2534.HypoidGear)

        @property
        def klingelnberg_cyclo_palloid_conical_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2536.KlingelnbergCycloPalloidConicalGear":
            from mastapy.system_model.part_model.gears import _2536

            return self._parent._cast(_2536.KlingelnbergCycloPalloidConicalGear)

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2538.KlingelnbergCycloPalloidHypoidGear":
            from mastapy.system_model.part_model.gears import _2538

            return self._parent._cast(_2538.KlingelnbergCycloPalloidHypoidGear)

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2540.KlingelnbergCycloPalloidSpiralBevelGear":
            from mastapy.system_model.part_model.gears import _2540

            return self._parent._cast(_2540.KlingelnbergCycloPalloidSpiralBevelGear)

        @property
        def spiral_bevel_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2543.SpiralBevelGear":
            from mastapy.system_model.part_model.gears import _2543

            return self._parent._cast(_2543.SpiralBevelGear)

        @property
        def straight_bevel_diff_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2545.StraightBevelDiffGear":
            from mastapy.system_model.part_model.gears import _2545

            return self._parent._cast(_2545.StraightBevelDiffGear)

        @property
        def straight_bevel_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2547.StraightBevelGear":
            from mastapy.system_model.part_model.gears import _2547

            return self._parent._cast(_2547.StraightBevelGear)

        @property
        def straight_bevel_planet_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2549.StraightBevelPlanetGear":
            from mastapy.system_model.part_model.gears import _2549

            return self._parent._cast(_2549.StraightBevelPlanetGear)

        @property
        def straight_bevel_sun_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2550.StraightBevelSunGear":
            from mastapy.system_model.part_model.gears import _2550

            return self._parent._cast(_2550.StraightBevelSunGear)

        @property
        def zerol_bevel_gear(
            self: "ConicalGear._Cast_ConicalGear",
        ) -> "_2553.ZerolBevelGear":
            from mastapy.system_model.part_model.gears import _2553

            return self._parent._cast(_2553.ZerolBevelGear)

        @property
        def conical_gear(self: "ConicalGear._Cast_ConicalGear") -> "ConicalGear":
            return self._parent

        def __getattr__(self: "ConicalGear._Cast_ConicalGear", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ConicalGear.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def length(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Length

        if temp is None:
            return 0.0

        return temp

    @property
    def orientation(self: Self) -> "_2531.GearOrientations":
        """mastapy.system_model.part_model.gears.GearOrientations"""
        temp = self.wrapped.Orientation

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.PartModel.Gears.GearOrientations"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.part_model.gears._2531", "GearOrientations"
        )(value)

    @orientation.setter
    @enforce_parameter_types
    def orientation(self: Self, value: "_2531.GearOrientations"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.SystemModel.PartModel.Gears.GearOrientations"
        )
        self.wrapped.Orientation = value

    @property
    def active_gear_design(self: Self) -> "_1154.ConicalGearDesign":
        """mastapy.gears.gear_designs.conical.ConicalGearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ActiveGearDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def conical_gear_design(self: Self) -> "_1154.ConicalGearDesign":
        """mastapy.gears.gear_designs.conical.ConicalGearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConicalGearDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: Self) -> "ConicalGear._Cast_ConicalGear":
        return self._Cast_ConicalGear(self)



"""TorqueConverterTurbineCompoundSystemDeflection"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2890
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_TURBINE_COMPOUND_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound",
    "TorqueConverterTurbineCompoundSystemDeflection",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.couplings import _2610
    from mastapy.system_model.analyses_and_results.system_deflections import _2831
    from mastapy.system_model.analyses_and_results.system_deflections.compound import (
        _2929,
        _2876,
        _2931,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("TorqueConverterTurbineCompoundSystemDeflection",)


Self = TypeVar("Self", bound="TorqueConverterTurbineCompoundSystemDeflection")


class TorqueConverterTurbineCompoundSystemDeflection(
    _2890.CouplingHalfCompoundSystemDeflection
):
    """TorqueConverterTurbineCompoundSystemDeflection

    This is a mastapy class.
    """

    TYPE = _TORQUE_CONVERTER_TURBINE_COMPOUND_SYSTEM_DEFLECTION
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_TorqueConverterTurbineCompoundSystemDeflection"
    )

    class _Cast_TorqueConverterTurbineCompoundSystemDeflection:
        """Special nested class for casting TorqueConverterTurbineCompoundSystemDeflection to subclasses."""

        def __init__(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
            parent: "TorqueConverterTurbineCompoundSystemDeflection",
        ):
            self._parent = parent

        @property
        def coupling_half_compound_system_deflection(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_2890.CouplingHalfCompoundSystemDeflection":
            return self._parent._cast(_2890.CouplingHalfCompoundSystemDeflection)

        @property
        def mountable_component_compound_system_deflection(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_2929.MountableComponentCompoundSystemDeflection":
            from mastapy.system_model.analyses_and_results.system_deflections.compound import (
                _2929,
            )

            return self._parent._cast(_2929.MountableComponentCompoundSystemDeflection)

        @property
        def component_compound_system_deflection(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_2876.ComponentCompoundSystemDeflection":
            from mastapy.system_model.analyses_and_results.system_deflections.compound import (
                _2876,
            )

            return self._parent._cast(_2876.ComponentCompoundSystemDeflection)

        @property
        def part_compound_system_deflection(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_2931.PartCompoundSystemDeflection":
            from mastapy.system_model.analyses_and_results.system_deflections.compound import (
                _2931,
            )

            return self._parent._cast(_2931.PartCompoundSystemDeflection)

        @property
        def part_compound_analysis(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def torque_converter_turbine_compound_system_deflection(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
        ) -> "TorqueConverterTurbineCompoundSystemDeflection":
            return self._parent

        def __getattr__(
            self: "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "TorqueConverterTurbineCompoundSystemDeflection.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2610.TorqueConverterTurbine":
        """mastapy.system_model.part_model.couplings.TorqueConverterTurbine

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def component_analysis_cases_ready(
        self: Self,
    ) -> "List[_2831.TorqueConverterTurbineSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.TorqueConverterTurbineSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def component_analysis_cases(
        self: Self,
    ) -> "List[_2831.TorqueConverterTurbineSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.TorqueConverterTurbineSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "TorqueConverterTurbineCompoundSystemDeflection._Cast_TorqueConverterTurbineCompoundSystemDeflection":
        return self._Cast_TorqueConverterTurbineCompoundSystemDeflection(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._703 import CurveInLinkedList
    from ._704 import CustomisableEdgeProfile
    from ._705 import CylindricalFormedWheelGrinderDatabase
    from ._706 import CylindricalGearAbstractCutterDesign
    from ._707 import CylindricalGearFormGrindingWheel
    from ._708 import CylindricalGearGrindingWorm
    from ._709 import CylindricalGearHobDesign
    from ._710 import CylindricalGearPlungeShaver
    from ._711 import CylindricalGearPlungeShaverDatabase
    from ._712 import CylindricalGearRackDesign
    from ._713 import CylindricalGearRealCutterDesign
    from ._714 import CylindricalGearShaper
    from ._715 import CylindricalGearShaver
    from ._716 import CylindricalGearShaverDatabase
    from ._717 import CylindricalWormGrinderDatabase
    from ._718 import InvoluteCutterDesign
    from ._719 import MutableCommon
    from ._720 import MutableCurve
    from ._721 import MutableFillet
    from ._722 import RoughCutterCreationSettings
else:
    import_structure = {
        "_703": ["CurveInLinkedList"],
        "_704": ["CustomisableEdgeProfile"],
        "_705": ["CylindricalFormedWheelGrinderDatabase"],
        "_706": ["CylindricalGearAbstractCutterDesign"],
        "_707": ["CylindricalGearFormGrindingWheel"],
        "_708": ["CylindricalGearGrindingWorm"],
        "_709": ["CylindricalGearHobDesign"],
        "_710": ["CylindricalGearPlungeShaver"],
        "_711": ["CylindricalGearPlungeShaverDatabase"],
        "_712": ["CylindricalGearRackDesign"],
        "_713": ["CylindricalGearRealCutterDesign"],
        "_714": ["CylindricalGearShaper"],
        "_715": ["CylindricalGearShaver"],
        "_716": ["CylindricalGearShaverDatabase"],
        "_717": ["CylindricalWormGrinderDatabase"],
        "_718": ["InvoluteCutterDesign"],
        "_719": ["MutableCommon"],
        "_720": ["MutableCurve"],
        "_721": ["MutableFillet"],
        "_722": ["RoughCutterCreationSettings"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "CurveInLinkedList",
    "CustomisableEdgeProfile",
    "CylindricalFormedWheelGrinderDatabase",
    "CylindricalGearAbstractCutterDesign",
    "CylindricalGearFormGrindingWheel",
    "CylindricalGearGrindingWorm",
    "CylindricalGearHobDesign",
    "CylindricalGearPlungeShaver",
    "CylindricalGearPlungeShaverDatabase",
    "CylindricalGearRackDesign",
    "CylindricalGearRealCutterDesign",
    "CylindricalGearShaper",
    "CylindricalGearShaver",
    "CylindricalGearShaverDatabase",
    "CylindricalWormGrinderDatabase",
    "InvoluteCutterDesign",
    "MutableCommon",
    "MutableCurve",
    "MutableFillet",
    "RoughCutterCreationSettings",
)



"""ConnectionModalAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.analysis_cases import _7541
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CONNECTION_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses",
    "ConnectionModalAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets import _2272
    from mastapy.system_model.analyses_and_results.modal_analyses import (
        _4654,
        _4575,
        _4576,
        _4581,
        _4583,
        _4588,
        _4593,
        _4596,
        _4598,
        _4601,
        _4604,
        _4610,
        _4613,
        _4617,
        _4619,
        _4620,
        _4629,
        _4635,
        _4639,
        _4642,
        _4643,
        _4646,
        _4649,
        _4663,
        _4666,
        _4673,
        _4675,
        _4681,
        _4683,
        _4686,
        _4689,
        _4692,
        _4701,
        _4710,
        _4713,
    )
    from mastapy.system_model.analyses_and_results.modal_analyses.reporting import _4726
    from mastapy.system_model.analyses_and_results.system_deflections import _2727
    from mastapy.system_model.analyses_and_results.analysis_cases import _7538
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("ConnectionModalAnalysis",)


Self = TypeVar("Self", bound="ConnectionModalAnalysis")


class ConnectionModalAnalysis(_7541.ConnectionStaticLoadAnalysisCase):
    """ConnectionModalAnalysis

    This is a mastapy class.
    """

    TYPE = _CONNECTION_MODAL_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ConnectionModalAnalysis")

    class _Cast_ConnectionModalAnalysis:
        """Special nested class for casting ConnectionModalAnalysis to subclasses."""

        def __init__(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
            parent: "ConnectionModalAnalysis",
        ):
            self._parent = parent

        @property
        def connection_static_load_analysis_case(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_7541.ConnectionStaticLoadAnalysisCase":
            return self._parent._cast(_7541.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def abstract_shaft_to_mountable_component_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4575.AbstractShaftToMountableComponentConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4575

            return self._parent._cast(
                _4575.AbstractShaftToMountableComponentConnectionModalAnalysis
            )

        @property
        def agma_gleason_conical_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4576.AGMAGleasonConicalGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4576

            return self._parent._cast(_4576.AGMAGleasonConicalGearMeshModalAnalysis)

        @property
        def belt_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4581.BeltConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4581

            return self._parent._cast(_4581.BeltConnectionModalAnalysis)

        @property
        def bevel_differential_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4583.BevelDifferentialGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4583

            return self._parent._cast(_4583.BevelDifferentialGearMeshModalAnalysis)

        @property
        def bevel_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4588.BevelGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4588

            return self._parent._cast(_4588.BevelGearMeshModalAnalysis)

        @property
        def clutch_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4593.ClutchConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4593

            return self._parent._cast(_4593.ClutchConnectionModalAnalysis)

        @property
        def coaxial_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4596.CoaxialConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4596

            return self._parent._cast(_4596.CoaxialConnectionModalAnalysis)

        @property
        def concept_coupling_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4598.ConceptCouplingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4598

            return self._parent._cast(_4598.ConceptCouplingConnectionModalAnalysis)

        @property
        def concept_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4601.ConceptGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4601

            return self._parent._cast(_4601.ConceptGearMeshModalAnalysis)

        @property
        def conical_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4604.ConicalGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4604

            return self._parent._cast(_4604.ConicalGearMeshModalAnalysis)

        @property
        def coupling_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4610.CouplingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4610

            return self._parent._cast(_4610.CouplingConnectionModalAnalysis)

        @property
        def cvt_belt_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4613.CVTBeltConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4613

            return self._parent._cast(_4613.CVTBeltConnectionModalAnalysis)

        @property
        def cycloidal_disc_central_bearing_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4617.CycloidalDiscCentralBearingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4617

            return self._parent._cast(
                _4617.CycloidalDiscCentralBearingConnectionModalAnalysis
            )

        @property
        def cycloidal_disc_planetary_bearing_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4619.CycloidalDiscPlanetaryBearingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4619

            return self._parent._cast(
                _4619.CycloidalDiscPlanetaryBearingConnectionModalAnalysis
            )

        @property
        def cylindrical_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4620.CylindricalGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4620

            return self._parent._cast(_4620.CylindricalGearMeshModalAnalysis)

        @property
        def face_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4629.FaceGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4629

            return self._parent._cast(_4629.FaceGearMeshModalAnalysis)

        @property
        def gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4635.GearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4635

            return self._parent._cast(_4635.GearMeshModalAnalysis)

        @property
        def hypoid_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4639.HypoidGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4639

            return self._parent._cast(_4639.HypoidGearMeshModalAnalysis)

        @property
        def inter_mountable_component_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4642.InterMountableComponentConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4642

            return self._parent._cast(
                _4642.InterMountableComponentConnectionModalAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_conical_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4643.KlingelnbergCycloPalloidConicalGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4643

            return self._parent._cast(
                _4643.KlingelnbergCycloPalloidConicalGearMeshModalAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4646.KlingelnbergCycloPalloidHypoidGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4646

            return self._parent._cast(
                _4646.KlingelnbergCycloPalloidHypoidGearMeshModalAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4649.KlingelnbergCycloPalloidSpiralBevelGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4649

            return self._parent._cast(
                _4649.KlingelnbergCycloPalloidSpiralBevelGearMeshModalAnalysis
            )

        @property
        def part_to_part_shear_coupling_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4663.PartToPartShearCouplingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4663

            return self._parent._cast(
                _4663.PartToPartShearCouplingConnectionModalAnalysis
            )

        @property
        def planetary_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4666.PlanetaryConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4666

            return self._parent._cast(_4666.PlanetaryConnectionModalAnalysis)

        @property
        def ring_pins_to_disc_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4673.RingPinsToDiscConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4673

            return self._parent._cast(_4673.RingPinsToDiscConnectionModalAnalysis)

        @property
        def rolling_ring_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4675.RollingRingConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4675

            return self._parent._cast(_4675.RollingRingConnectionModalAnalysis)

        @property
        def shaft_to_mountable_component_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4681.ShaftToMountableComponentConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4681

            return self._parent._cast(
                _4681.ShaftToMountableComponentConnectionModalAnalysis
            )

        @property
        def spiral_bevel_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4683.SpiralBevelGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4683

            return self._parent._cast(_4683.SpiralBevelGearMeshModalAnalysis)

        @property
        def spring_damper_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4686.SpringDamperConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4686

            return self._parent._cast(_4686.SpringDamperConnectionModalAnalysis)

        @property
        def straight_bevel_diff_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4689.StraightBevelDiffGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4689

            return self._parent._cast(_4689.StraightBevelDiffGearMeshModalAnalysis)

        @property
        def straight_bevel_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4692.StraightBevelGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4692

            return self._parent._cast(_4692.StraightBevelGearMeshModalAnalysis)

        @property
        def torque_converter_connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4701.TorqueConverterConnectionModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4701

            return self._parent._cast(_4701.TorqueConverterConnectionModalAnalysis)

        @property
        def worm_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4710.WormGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4710

            return self._parent._cast(_4710.WormGearMeshModalAnalysis)

        @property
        def zerol_bevel_gear_mesh_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "_4713.ZerolBevelGearMeshModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4713

            return self._parent._cast(_4713.ZerolBevelGearMeshModalAnalysis)

        @property
        def connection_modal_analysis(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis",
        ) -> "ConnectionModalAnalysis":
            return self._parent

        def __getattr__(
            self: "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ConnectionModalAnalysis.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2272.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_design(self: Self) -> "_2272.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def modal_analysis(self: Self) -> "_4654.ModalAnalysis":
        """mastapy.system_model.analyses_and_results.modal_analyses.ModalAnalysis

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModalAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def excited_modes_summary(
        self: Self,
    ) -> "List[_4726.SingleExcitationResultsModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.reporting.SingleExcitationResultsModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ExcitedModesSummary

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def system_deflection_results(self: Self) -> "_2727.ConnectionSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.ConnectionSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: Self) -> "ConnectionModalAnalysis._Cast_ConnectionModalAnalysis":
        return self._Cast_ConnectionModalAnalysis(self)



"""BoltedJointMaterial"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor
from mastapy.materials import _269
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BOLTED_JOINT_MATERIAL = python_net_import("SMT.MastaAPI.Bolts", "BoltedJointMaterial")

if TYPE_CHECKING:
    from mastapy.math_utility import _1534
    from mastapy.bolts import _1469
    from mastapy.utility.databases import _1829


__docformat__ = "restructuredtext en"
__all__ = ("BoltedJointMaterial",)


Self = TypeVar("Self", bound="BoltedJointMaterial")


class BoltedJointMaterial(_269.Material):
    """BoltedJointMaterial

    This is a mastapy class.
    """

    TYPE = _BOLTED_JOINT_MATERIAL
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BoltedJointMaterial")

    class _Cast_BoltedJointMaterial:
        """Special nested class for casting BoltedJointMaterial to subclasses."""

        def __init__(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial",
            parent: "BoltedJointMaterial",
        ):
            self._parent = parent

        @property
        def material(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial",
        ) -> "_269.Material":
            return self._parent._cast(_269.Material)

        @property
        def named_database_item(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial",
        ) -> "_1829.NamedDatabaseItem":
            from mastapy.utility.databases import _1829

            return self._parent._cast(_1829.NamedDatabaseItem)

        @property
        def bolt_material(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial",
        ) -> "_1469.BoltMaterial":
            from mastapy.bolts import _1469

            return self._parent._cast(_1469.BoltMaterial)

        @property
        def bolted_joint_material(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial",
        ) -> "BoltedJointMaterial":
            return self._parent

        def __getattr__(
            self: "BoltedJointMaterial._Cast_BoltedJointMaterial", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BoltedJointMaterial.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def coefficient_of_thermal_expansion_at_20c(self: Self) -> "float":
        """float"""
        temp = self.wrapped.CoefficientOfThermalExpansionAt20C

        if temp is None:
            return 0.0

        return temp

    @coefficient_of_thermal_expansion_at_20c.setter
    @enforce_parameter_types
    def coefficient_of_thermal_expansion_at_20c(self: Self, value: "float"):
        self.wrapped.CoefficientOfThermalExpansionAt20C = (
            float(value) if value is not None else 0.0
        )

    @property
    def limiting_surface_pressure(self: Self) -> "float":
        """float"""
        temp = self.wrapped.LimitingSurfacePressure

        if temp is None:
            return 0.0

        return temp

    @limiting_surface_pressure.setter
    @enforce_parameter_types
    def limiting_surface_pressure(self: Self, value: "float"):
        self.wrapped.LimitingSurfacePressure = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_tensile_strength(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MinimumTensileStrength

        if temp is None:
            return 0.0

        return temp

    @minimum_tensile_strength.setter
    @enforce_parameter_types
    def minimum_tensile_strength(self: Self, value: "float"):
        self.wrapped.MinimumTensileStrength = float(value) if value is not None else 0.0

    @property
    def modulus_of_elasticity_at_20c(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ModulusOfElasticityAt20C

        if temp is None:
            return 0.0

        return temp

    @modulus_of_elasticity_at_20c.setter
    @enforce_parameter_types
    def modulus_of_elasticity_at_20c(self: Self, value: "float"):
        self.wrapped.ModulusOfElasticityAt20C = (
            float(value) if value is not None else 0.0
        )

    @property
    def proof_stress(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ProofStress

        if temp is None:
            return 0.0

        return temp

    @proof_stress.setter
    @enforce_parameter_types
    def proof_stress(self: Self, value: "float"):
        self.wrapped.ProofStress = float(value) if value is not None else 0.0

    @property
    def shearing_strength(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ShearingStrength

        if temp is None:
            return 0.0

        return temp

    @shearing_strength.setter
    @enforce_parameter_types
    def shearing_strength(self: Self, value: "float"):
        self.wrapped.ShearingStrength = float(value) if value is not None else 0.0

    @property
    def stress_endurance_limit(self: Self) -> "float":
        """float"""
        temp = self.wrapped.StressEnduranceLimit

        if temp is None:
            return 0.0

        return temp

    @stress_endurance_limit.setter
    @enforce_parameter_types
    def stress_endurance_limit(self: Self, value: "float"):
        self.wrapped.StressEnduranceLimit = float(value) if value is not None else 0.0

    @property
    def temperature_dependent_coefficient_of_thermal_expansion(
        self: Self,
    ) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.TemperatureDependentCoefficientOfThermalExpansion

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @temperature_dependent_coefficient_of_thermal_expansion.setter
    @enforce_parameter_types
    def temperature_dependent_coefficient_of_thermal_expansion(
        self: Self, value: "_1534.Vector2DListAccessor"
    ):
        self.wrapped.TemperatureDependentCoefficientOfThermalExpansion = value.wrapped

    @property
    def temperature_dependent_youngs_moduli(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.TemperatureDependentYoungsModuli

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @temperature_dependent_youngs_moduli.setter
    @enforce_parameter_types
    def temperature_dependent_youngs_moduli(
        self: Self, value: "_1534.Vector2DListAccessor"
    ):
        self.wrapped.TemperatureDependentYoungsModuli = value.wrapped

    @property
    def cast_to(self: Self) -> "BoltedJointMaterial._Cast_BoltedJointMaterial":
        return self._Cast_BoltedJointMaterial(self)



"""LoadedRollerBearingRow"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from PIL.Image import Image

from mastapy._internal import constructor, conversion
from mastapy.bearings.bearing_results.rolling import _2034
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_LOADED_ROLLER_BEARING_ROW = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling", "LoadedRollerBearingRow"
)

if TYPE_CHECKING:
    from mastapy.bearings.bearing_results.rolling import (
        _2029,
        _1970,
        _1990,
        _1995,
        _1998,
        _2006,
        _2010,
        _2022,
        _2025,
        _2041,
        _2044,
        _2049,
        _2058,
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedRollerBearingRow",)


Self = TypeVar("Self", bound="LoadedRollerBearingRow")


class LoadedRollerBearingRow(_2034.LoadedRollingBearingRow):
    """LoadedRollerBearingRow

    This is a mastapy class.
    """

    TYPE = _LOADED_ROLLER_BEARING_ROW
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_LoadedRollerBearingRow")

    class _Cast_LoadedRollerBearingRow:
        """Special nested class for casting LoadedRollerBearingRow to subclasses."""

        def __init__(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
            parent: "LoadedRollerBearingRow",
        ):
            self._parent = parent

        @property
        def loaded_rolling_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2034.LoadedRollingBearingRow":
            return self._parent._cast(_2034.LoadedRollingBearingRow)

        @property
        def loaded_asymmetric_spherical_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_1990.LoadedAsymmetricSphericalRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _1990

            return self._parent._cast(_1990.LoadedAsymmetricSphericalRollerBearingRow)

        @property
        def loaded_axial_thrust_cylindrical_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_1995.LoadedAxialThrustCylindricalRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _1995

            return self._parent._cast(
                _1995.LoadedAxialThrustCylindricalRollerBearingRow
            )

        @property
        def loaded_axial_thrust_needle_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_1998.LoadedAxialThrustNeedleRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _1998

            return self._parent._cast(_1998.LoadedAxialThrustNeedleRollerBearingRow)

        @property
        def loaded_crossed_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2006.LoadedCrossedRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2006

            return self._parent._cast(_2006.LoadedCrossedRollerBearingRow)

        @property
        def loaded_cylindrical_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2010.LoadedCylindricalRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2010

            return self._parent._cast(_2010.LoadedCylindricalRollerBearingRow)

        @property
        def loaded_needle_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2022.LoadedNeedleRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2022

            return self._parent._cast(_2022.LoadedNeedleRollerBearingRow)

        @property
        def loaded_non_barrel_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2025.LoadedNonBarrelRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2025

            return self._parent._cast(_2025.LoadedNonBarrelRollerBearingRow)

        @property
        def loaded_spherical_roller_radial_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2041.LoadedSphericalRollerRadialBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2041

            return self._parent._cast(_2041.LoadedSphericalRollerRadialBearingRow)

        @property
        def loaded_spherical_roller_thrust_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2044.LoadedSphericalRollerThrustBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2044

            return self._parent._cast(_2044.LoadedSphericalRollerThrustBearingRow)

        @property
        def loaded_taper_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2049.LoadedTaperRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2049

            return self._parent._cast(_2049.LoadedTaperRollerBearingRow)

        @property
        def loaded_toroidal_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "_2058.LoadedToroidalRollerBearingRow":
            from mastapy.bearings.bearing_results.rolling import _2058

            return self._parent._cast(_2058.LoadedToroidalRollerBearingRow)

        @property
        def loaded_roller_bearing_row(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow",
        ) -> "LoadedRollerBearingRow":
            return self._parent

        def __getattr__(
            self: "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "LoadedRollerBearingRow.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def depth_of_maximum_shear_stress_chart_inner(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DepthOfMaximumShearStressChartInner

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def depth_of_maximum_shear_stress_chart_outer(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DepthOfMaximumShearStressChartOuter

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def hertzian_contact_width_inner(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HertzianContactWidthInner

        if temp is None:
            return 0.0

        return temp

    @property
    def hertzian_contact_width_outer(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HertzianContactWidthOuter

        if temp is None:
            return 0.0

        return temp

    @property
    def inner_race_profile_warning(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerRaceProfileWarning

        if temp is None:
            return ""

        return temp

    @property
    def maximum_normal_edge_stress_inner(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumNormalEdgeStressInner

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_normal_edge_stress_outer(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumNormalEdgeStressOuter

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_shear_stress_inner(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumShearStressInner

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_shear_stress_outer(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumShearStressOuter

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_race_profile_warning(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRaceProfileWarning

        if temp is None:
            return ""

        return temp

    @property
    def roller_profile_warning(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollerProfileWarning

        if temp is None:
            return ""

        return temp

    @property
    def shear_stress_chart_inner(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShearStressChartInner

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def shear_stress_chart_outer(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShearStressChartOuter

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def loaded_bearing(self: Self) -> "_2029.LoadedRollerBearingResults":
        """mastapy.bearings.bearing_results.rolling.LoadedRollerBearingResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadedBearing

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def lamina_dynamic_equivalent_loads(
        self: Self,
    ) -> "List[_1970.ForceAtLaminaGroupReportable]":
        """List[mastapy.bearings.bearing_results.rolling.ForceAtLaminaGroupReportable]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LaminaDynamicEquivalentLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "LoadedRollerBearingRow._Cast_LoadedRollerBearingRow":
        return self._Cast_LoadedRollerBearingRow(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._902 import BarForPareto
    from ._903 import CandidateDisplayChoice
    from ._904 import ChartInfoBase
    from ._905 import CylindricalGearSetParetoOptimiser
    from ._906 import DesignSpaceSearchBase
    from ._907 import DesignSpaceSearchCandidateBase
    from ._908 import FaceGearSetParetoOptimiser
    from ._909 import GearNameMapper
    from ._910 import GearNamePicker
    from ._911 import GearSetOptimiserCandidate
    from ._912 import GearSetParetoOptimiser
    from ._913 import HypoidGearSetParetoOptimiser
    from ._914 import InputSliderForPareto
    from ._915 import LargerOrSmaller
    from ._916 import MicroGeometryDesignSpaceSearch
    from ._917 import MicroGeometryDesignSpaceSearchCandidate
    from ._918 import MicroGeometryDesignSpaceSearchChartInformation
    from ._919 import MicroGeometryGearSetDesignSpaceSearch
    from ._920 import MicroGeometryGearSetDesignSpaceSearchStrategyDatabase
    from ._921 import MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase
    from ._922 import OptimisationTarget
    from ._923 import ParetoConicalRatingOptimisationStrategyDatabase
    from ._924 import ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase
    from ._925 import ParetoCylindricalGearSetOptimisationStrategyDatabase
    from ._926 import ParetoCylindricalRatingOptimisationStrategyDatabase
    from ._927 import ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase
    from ._928 import ParetoFaceGearSetOptimisationStrategyDatabase
    from ._929 import ParetoFaceRatingOptimisationStrategyDatabase
    from ._930 import ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase
    from ._931 import ParetoHypoidGearSetOptimisationStrategyDatabase
    from ._932 import ParetoOptimiserChartInformation
    from ._933 import ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase
    from ._934 import ParetoSpiralBevelGearSetOptimisationStrategyDatabase
    from ._935 import ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase
    from ._936 import ParetoStraightBevelGearSetOptimisationStrategyDatabase
    from ._937 import ReasonsForInvalidDesigns
    from ._938 import SpiralBevelGearSetParetoOptimiser
    from ._939 import StraightBevelGearSetParetoOptimiser
else:
    import_structure = {
        "_902": ["BarForPareto"],
        "_903": ["CandidateDisplayChoice"],
        "_904": ["ChartInfoBase"],
        "_905": ["CylindricalGearSetParetoOptimiser"],
        "_906": ["DesignSpaceSearchBase"],
        "_907": ["DesignSpaceSearchCandidateBase"],
        "_908": ["FaceGearSetParetoOptimiser"],
        "_909": ["GearNameMapper"],
        "_910": ["GearNamePicker"],
        "_911": ["GearSetOptimiserCandidate"],
        "_912": ["GearSetParetoOptimiser"],
        "_913": ["HypoidGearSetParetoOptimiser"],
        "_914": ["InputSliderForPareto"],
        "_915": ["LargerOrSmaller"],
        "_916": ["MicroGeometryDesignSpaceSearch"],
        "_917": ["MicroGeometryDesignSpaceSearchCandidate"],
        "_918": ["MicroGeometryDesignSpaceSearchChartInformation"],
        "_919": ["MicroGeometryGearSetDesignSpaceSearch"],
        "_920": ["MicroGeometryGearSetDesignSpaceSearchStrategyDatabase"],
        "_921": ["MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase"],
        "_922": ["OptimisationTarget"],
        "_923": ["ParetoConicalRatingOptimisationStrategyDatabase"],
        "_924": ["ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase"],
        "_925": ["ParetoCylindricalGearSetOptimisationStrategyDatabase"],
        "_926": ["ParetoCylindricalRatingOptimisationStrategyDatabase"],
        "_927": ["ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase"],
        "_928": ["ParetoFaceGearSetOptimisationStrategyDatabase"],
        "_929": ["ParetoFaceRatingOptimisationStrategyDatabase"],
        "_930": ["ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase"],
        "_931": ["ParetoHypoidGearSetOptimisationStrategyDatabase"],
        "_932": ["ParetoOptimiserChartInformation"],
        "_933": ["ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase"],
        "_934": ["ParetoSpiralBevelGearSetOptimisationStrategyDatabase"],
        "_935": ["ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase"],
        "_936": ["ParetoStraightBevelGearSetOptimisationStrategyDatabase"],
        "_937": ["ReasonsForInvalidDesigns"],
        "_938": ["SpiralBevelGearSetParetoOptimiser"],
        "_939": ["StraightBevelGearSetParetoOptimiser"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "BarForPareto",
    "CandidateDisplayChoice",
    "ChartInfoBase",
    "CylindricalGearSetParetoOptimiser",
    "DesignSpaceSearchBase",
    "DesignSpaceSearchCandidateBase",
    "FaceGearSetParetoOptimiser",
    "GearNameMapper",
    "GearNamePicker",
    "GearSetOptimiserCandidate",
    "GearSetParetoOptimiser",
    "HypoidGearSetParetoOptimiser",
    "InputSliderForPareto",
    "LargerOrSmaller",
    "MicroGeometryDesignSpaceSearch",
    "MicroGeometryDesignSpaceSearchCandidate",
    "MicroGeometryDesignSpaceSearchChartInformation",
    "MicroGeometryGearSetDesignSpaceSearch",
    "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase",
    "OptimisationTarget",
    "ParetoConicalRatingOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetOptimisationStrategyDatabase",
    "ParetoCylindricalRatingOptimisationStrategyDatabase",
    "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoFaceGearSetOptimisationStrategyDatabase",
    "ParetoFaceRatingOptimisationStrategyDatabase",
    "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoHypoidGearSetOptimisationStrategyDatabase",
    "ParetoOptimiserChartInformation",
    "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoSpiralBevelGearSetOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetOptimisationStrategyDatabase",
    "ReasonsForInvalidDesigns",
    "SpiralBevelGearSetParetoOptimiser",
    "StraightBevelGearSetParetoOptimiser",
)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._6408 import AbstractAssemblyCompoundDynamicAnalysis
    from ._6409 import AbstractShaftCompoundDynamicAnalysis
    from ._6410 import AbstractShaftOrHousingCompoundDynamicAnalysis
    from ._6411 import (
        AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from ._6412 import AGMAGleasonConicalGearCompoundDynamicAnalysis
    from ._6413 import AGMAGleasonConicalGearMeshCompoundDynamicAnalysis
    from ._6414 import AGMAGleasonConicalGearSetCompoundDynamicAnalysis
    from ._6415 import AssemblyCompoundDynamicAnalysis
    from ._6416 import BearingCompoundDynamicAnalysis
    from ._6417 import BeltConnectionCompoundDynamicAnalysis
    from ._6418 import BeltDriveCompoundDynamicAnalysis
    from ._6419 import BevelDifferentialGearCompoundDynamicAnalysis
    from ._6420 import BevelDifferentialGearMeshCompoundDynamicAnalysis
    from ._6421 import BevelDifferentialGearSetCompoundDynamicAnalysis
    from ._6422 import BevelDifferentialPlanetGearCompoundDynamicAnalysis
    from ._6423 import BevelDifferentialSunGearCompoundDynamicAnalysis
    from ._6424 import BevelGearCompoundDynamicAnalysis
    from ._6425 import BevelGearMeshCompoundDynamicAnalysis
    from ._6426 import BevelGearSetCompoundDynamicAnalysis
    from ._6427 import BoltCompoundDynamicAnalysis
    from ._6428 import BoltedJointCompoundDynamicAnalysis
    from ._6429 import ClutchCompoundDynamicAnalysis
    from ._6430 import ClutchConnectionCompoundDynamicAnalysis
    from ._6431 import ClutchHalfCompoundDynamicAnalysis
    from ._6432 import CoaxialConnectionCompoundDynamicAnalysis
    from ._6433 import ComponentCompoundDynamicAnalysis
    from ._6434 import ConceptCouplingCompoundDynamicAnalysis
    from ._6435 import ConceptCouplingConnectionCompoundDynamicAnalysis
    from ._6436 import ConceptCouplingHalfCompoundDynamicAnalysis
    from ._6437 import ConceptGearCompoundDynamicAnalysis
    from ._6438 import ConceptGearMeshCompoundDynamicAnalysis
    from ._6439 import ConceptGearSetCompoundDynamicAnalysis
    from ._6440 import ConicalGearCompoundDynamicAnalysis
    from ._6441 import ConicalGearMeshCompoundDynamicAnalysis
    from ._6442 import ConicalGearSetCompoundDynamicAnalysis
    from ._6443 import ConnectionCompoundDynamicAnalysis
    from ._6444 import ConnectorCompoundDynamicAnalysis
    from ._6445 import CouplingCompoundDynamicAnalysis
    from ._6446 import CouplingConnectionCompoundDynamicAnalysis
    from ._6447 import CouplingHalfCompoundDynamicAnalysis
    from ._6448 import CVTBeltConnectionCompoundDynamicAnalysis
    from ._6449 import CVTCompoundDynamicAnalysis
    from ._6450 import CVTPulleyCompoundDynamicAnalysis
    from ._6451 import CycloidalAssemblyCompoundDynamicAnalysis
    from ._6452 import CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis
    from ._6453 import CycloidalDiscCompoundDynamicAnalysis
    from ._6454 import CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis
    from ._6455 import CylindricalGearCompoundDynamicAnalysis
    from ._6456 import CylindricalGearMeshCompoundDynamicAnalysis
    from ._6457 import CylindricalGearSetCompoundDynamicAnalysis
    from ._6458 import CylindricalPlanetGearCompoundDynamicAnalysis
    from ._6459 import DatumCompoundDynamicAnalysis
    from ._6460 import ExternalCADModelCompoundDynamicAnalysis
    from ._6461 import FaceGearCompoundDynamicAnalysis
    from ._6462 import FaceGearMeshCompoundDynamicAnalysis
    from ._6463 import FaceGearSetCompoundDynamicAnalysis
    from ._6464 import FEPartCompoundDynamicAnalysis
    from ._6465 import FlexiblePinAssemblyCompoundDynamicAnalysis
    from ._6466 import GearCompoundDynamicAnalysis
    from ._6467 import GearMeshCompoundDynamicAnalysis
    from ._6468 import GearSetCompoundDynamicAnalysis
    from ._6469 import GuideDxfModelCompoundDynamicAnalysis
    from ._6470 import HypoidGearCompoundDynamicAnalysis
    from ._6471 import HypoidGearMeshCompoundDynamicAnalysis
    from ._6472 import HypoidGearSetCompoundDynamicAnalysis
    from ._6473 import InterMountableComponentConnectionCompoundDynamicAnalysis
    from ._6474 import KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis
    from ._6475 import KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis
    from ._6476 import KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis
    from ._6477 import KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis
    from ._6478 import KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis
    from ._6479 import KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis
    from ._6480 import KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis
    from ._6481 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis,
    )
    from ._6482 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis
    from ._6483 import MassDiscCompoundDynamicAnalysis
    from ._6484 import MeasurementComponentCompoundDynamicAnalysis
    from ._6485 import MountableComponentCompoundDynamicAnalysis
    from ._6486 import OilSealCompoundDynamicAnalysis
    from ._6487 import PartCompoundDynamicAnalysis
    from ._6488 import PartToPartShearCouplingCompoundDynamicAnalysis
    from ._6489 import PartToPartShearCouplingConnectionCompoundDynamicAnalysis
    from ._6490 import PartToPartShearCouplingHalfCompoundDynamicAnalysis
    from ._6491 import PlanetaryConnectionCompoundDynamicAnalysis
    from ._6492 import PlanetaryGearSetCompoundDynamicAnalysis
    from ._6493 import PlanetCarrierCompoundDynamicAnalysis
    from ._6494 import PointLoadCompoundDynamicAnalysis
    from ._6495 import PowerLoadCompoundDynamicAnalysis
    from ._6496 import PulleyCompoundDynamicAnalysis
    from ._6497 import RingPinsCompoundDynamicAnalysis
    from ._6498 import RingPinsToDiscConnectionCompoundDynamicAnalysis
    from ._6499 import RollingRingAssemblyCompoundDynamicAnalysis
    from ._6500 import RollingRingCompoundDynamicAnalysis
    from ._6501 import RollingRingConnectionCompoundDynamicAnalysis
    from ._6502 import RootAssemblyCompoundDynamicAnalysis
    from ._6503 import ShaftCompoundDynamicAnalysis
    from ._6504 import ShaftHubConnectionCompoundDynamicAnalysis
    from ._6505 import ShaftToMountableComponentConnectionCompoundDynamicAnalysis
    from ._6506 import SpecialisedAssemblyCompoundDynamicAnalysis
    from ._6507 import SpiralBevelGearCompoundDynamicAnalysis
    from ._6508 import SpiralBevelGearMeshCompoundDynamicAnalysis
    from ._6509 import SpiralBevelGearSetCompoundDynamicAnalysis
    from ._6510 import SpringDamperCompoundDynamicAnalysis
    from ._6511 import SpringDamperConnectionCompoundDynamicAnalysis
    from ._6512 import SpringDamperHalfCompoundDynamicAnalysis
    from ._6513 import StraightBevelDiffGearCompoundDynamicAnalysis
    from ._6514 import StraightBevelDiffGearMeshCompoundDynamicAnalysis
    from ._6515 import StraightBevelDiffGearSetCompoundDynamicAnalysis
    from ._6516 import StraightBevelGearCompoundDynamicAnalysis
    from ._6517 import StraightBevelGearMeshCompoundDynamicAnalysis
    from ._6518 import StraightBevelGearSetCompoundDynamicAnalysis
    from ._6519 import StraightBevelPlanetGearCompoundDynamicAnalysis
    from ._6520 import StraightBevelSunGearCompoundDynamicAnalysis
    from ._6521 import SynchroniserCompoundDynamicAnalysis
    from ._6522 import SynchroniserHalfCompoundDynamicAnalysis
    from ._6523 import SynchroniserPartCompoundDynamicAnalysis
    from ._6524 import SynchroniserSleeveCompoundDynamicAnalysis
    from ._6525 import TorqueConverterCompoundDynamicAnalysis
    from ._6526 import TorqueConverterConnectionCompoundDynamicAnalysis
    from ._6527 import TorqueConverterPumpCompoundDynamicAnalysis
    from ._6528 import TorqueConverterTurbineCompoundDynamicAnalysis
    from ._6529 import UnbalancedMassCompoundDynamicAnalysis
    from ._6530 import VirtualComponentCompoundDynamicAnalysis
    from ._6531 import WormGearCompoundDynamicAnalysis
    from ._6532 import WormGearMeshCompoundDynamicAnalysis
    from ._6533 import WormGearSetCompoundDynamicAnalysis
    from ._6534 import ZerolBevelGearCompoundDynamicAnalysis
    from ._6535 import ZerolBevelGearMeshCompoundDynamicAnalysis
    from ._6536 import ZerolBevelGearSetCompoundDynamicAnalysis
else:
    import_structure = {
        "_6408": ["AbstractAssemblyCompoundDynamicAnalysis"],
        "_6409": ["AbstractShaftCompoundDynamicAnalysis"],
        "_6410": ["AbstractShaftOrHousingCompoundDynamicAnalysis"],
        "_6411": ["AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis"],
        "_6412": ["AGMAGleasonConicalGearCompoundDynamicAnalysis"],
        "_6413": ["AGMAGleasonConicalGearMeshCompoundDynamicAnalysis"],
        "_6414": ["AGMAGleasonConicalGearSetCompoundDynamicAnalysis"],
        "_6415": ["AssemblyCompoundDynamicAnalysis"],
        "_6416": ["BearingCompoundDynamicAnalysis"],
        "_6417": ["BeltConnectionCompoundDynamicAnalysis"],
        "_6418": ["BeltDriveCompoundDynamicAnalysis"],
        "_6419": ["BevelDifferentialGearCompoundDynamicAnalysis"],
        "_6420": ["BevelDifferentialGearMeshCompoundDynamicAnalysis"],
        "_6421": ["BevelDifferentialGearSetCompoundDynamicAnalysis"],
        "_6422": ["BevelDifferentialPlanetGearCompoundDynamicAnalysis"],
        "_6423": ["BevelDifferentialSunGearCompoundDynamicAnalysis"],
        "_6424": ["BevelGearCompoundDynamicAnalysis"],
        "_6425": ["BevelGearMeshCompoundDynamicAnalysis"],
        "_6426": ["BevelGearSetCompoundDynamicAnalysis"],
        "_6427": ["BoltCompoundDynamicAnalysis"],
        "_6428": ["BoltedJointCompoundDynamicAnalysis"],
        "_6429": ["ClutchCompoundDynamicAnalysis"],
        "_6430": ["ClutchConnectionCompoundDynamicAnalysis"],
        "_6431": ["ClutchHalfCompoundDynamicAnalysis"],
        "_6432": ["CoaxialConnectionCompoundDynamicAnalysis"],
        "_6433": ["ComponentCompoundDynamicAnalysis"],
        "_6434": ["ConceptCouplingCompoundDynamicAnalysis"],
        "_6435": ["ConceptCouplingConnectionCompoundDynamicAnalysis"],
        "_6436": ["ConceptCouplingHalfCompoundDynamicAnalysis"],
        "_6437": ["ConceptGearCompoundDynamicAnalysis"],
        "_6438": ["ConceptGearMeshCompoundDynamicAnalysis"],
        "_6439": ["ConceptGearSetCompoundDynamicAnalysis"],
        "_6440": ["ConicalGearCompoundDynamicAnalysis"],
        "_6441": ["ConicalGearMeshCompoundDynamicAnalysis"],
        "_6442": ["ConicalGearSetCompoundDynamicAnalysis"],
        "_6443": ["ConnectionCompoundDynamicAnalysis"],
        "_6444": ["ConnectorCompoundDynamicAnalysis"],
        "_6445": ["CouplingCompoundDynamicAnalysis"],
        "_6446": ["CouplingConnectionCompoundDynamicAnalysis"],
        "_6447": ["CouplingHalfCompoundDynamicAnalysis"],
        "_6448": ["CVTBeltConnectionCompoundDynamicAnalysis"],
        "_6449": ["CVTCompoundDynamicAnalysis"],
        "_6450": ["CVTPulleyCompoundDynamicAnalysis"],
        "_6451": ["CycloidalAssemblyCompoundDynamicAnalysis"],
        "_6452": ["CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis"],
        "_6453": ["CycloidalDiscCompoundDynamicAnalysis"],
        "_6454": ["CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis"],
        "_6455": ["CylindricalGearCompoundDynamicAnalysis"],
        "_6456": ["CylindricalGearMeshCompoundDynamicAnalysis"],
        "_6457": ["CylindricalGearSetCompoundDynamicAnalysis"],
        "_6458": ["CylindricalPlanetGearCompoundDynamicAnalysis"],
        "_6459": ["DatumCompoundDynamicAnalysis"],
        "_6460": ["ExternalCADModelCompoundDynamicAnalysis"],
        "_6461": ["FaceGearCompoundDynamicAnalysis"],
        "_6462": ["FaceGearMeshCompoundDynamicAnalysis"],
        "_6463": ["FaceGearSetCompoundDynamicAnalysis"],
        "_6464": ["FEPartCompoundDynamicAnalysis"],
        "_6465": ["FlexiblePinAssemblyCompoundDynamicAnalysis"],
        "_6466": ["GearCompoundDynamicAnalysis"],
        "_6467": ["GearMeshCompoundDynamicAnalysis"],
        "_6468": ["GearSetCompoundDynamicAnalysis"],
        "_6469": ["GuideDxfModelCompoundDynamicAnalysis"],
        "_6470": ["HypoidGearCompoundDynamicAnalysis"],
        "_6471": ["HypoidGearMeshCompoundDynamicAnalysis"],
        "_6472": ["HypoidGearSetCompoundDynamicAnalysis"],
        "_6473": ["InterMountableComponentConnectionCompoundDynamicAnalysis"],
        "_6474": ["KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis"],
        "_6475": ["KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis"],
        "_6476": ["KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis"],
        "_6477": ["KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis"],
        "_6478": ["KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis"],
        "_6479": ["KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis"],
        "_6480": ["KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis"],
        "_6481": ["KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis"],
        "_6482": ["KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis"],
        "_6483": ["MassDiscCompoundDynamicAnalysis"],
        "_6484": ["MeasurementComponentCompoundDynamicAnalysis"],
        "_6485": ["MountableComponentCompoundDynamicAnalysis"],
        "_6486": ["OilSealCompoundDynamicAnalysis"],
        "_6487": ["PartCompoundDynamicAnalysis"],
        "_6488": ["PartToPartShearCouplingCompoundDynamicAnalysis"],
        "_6489": ["PartToPartShearCouplingConnectionCompoundDynamicAnalysis"],
        "_6490": ["PartToPartShearCouplingHalfCompoundDynamicAnalysis"],
        "_6491": ["PlanetaryConnectionCompoundDynamicAnalysis"],
        "_6492": ["PlanetaryGearSetCompoundDynamicAnalysis"],
        "_6493": ["PlanetCarrierCompoundDynamicAnalysis"],
        "_6494": ["PointLoadCompoundDynamicAnalysis"],
        "_6495": ["PowerLoadCompoundDynamicAnalysis"],
        "_6496": ["PulleyCompoundDynamicAnalysis"],
        "_6497": ["RingPinsCompoundDynamicAnalysis"],
        "_6498": ["RingPinsToDiscConnectionCompoundDynamicAnalysis"],
        "_6499": ["RollingRingAssemblyCompoundDynamicAnalysis"],
        "_6500": ["RollingRingCompoundDynamicAnalysis"],
        "_6501": ["RollingRingConnectionCompoundDynamicAnalysis"],
        "_6502": ["RootAssemblyCompoundDynamicAnalysis"],
        "_6503": ["ShaftCompoundDynamicAnalysis"],
        "_6504": ["ShaftHubConnectionCompoundDynamicAnalysis"],
        "_6505": ["ShaftToMountableComponentConnectionCompoundDynamicAnalysis"],
        "_6506": ["SpecialisedAssemblyCompoundDynamicAnalysis"],
        "_6507": ["SpiralBevelGearCompoundDynamicAnalysis"],
        "_6508": ["SpiralBevelGearMeshCompoundDynamicAnalysis"],
        "_6509": ["SpiralBevelGearSetCompoundDynamicAnalysis"],
        "_6510": ["SpringDamperCompoundDynamicAnalysis"],
        "_6511": ["SpringDamperConnectionCompoundDynamicAnalysis"],
        "_6512": ["SpringDamperHalfCompoundDynamicAnalysis"],
        "_6513": ["StraightBevelDiffGearCompoundDynamicAnalysis"],
        "_6514": ["StraightBevelDiffGearMeshCompoundDynamicAnalysis"],
        "_6515": ["StraightBevelDiffGearSetCompoundDynamicAnalysis"],
        "_6516": ["StraightBevelGearCompoundDynamicAnalysis"],
        "_6517": ["StraightBevelGearMeshCompoundDynamicAnalysis"],
        "_6518": ["StraightBevelGearSetCompoundDynamicAnalysis"],
        "_6519": ["StraightBevelPlanetGearCompoundDynamicAnalysis"],
        "_6520": ["StraightBevelSunGearCompoundDynamicAnalysis"],
        "_6521": ["SynchroniserCompoundDynamicAnalysis"],
        "_6522": ["SynchroniserHalfCompoundDynamicAnalysis"],
        "_6523": ["SynchroniserPartCompoundDynamicAnalysis"],
        "_6524": ["SynchroniserSleeveCompoundDynamicAnalysis"],
        "_6525": ["TorqueConverterCompoundDynamicAnalysis"],
        "_6526": ["TorqueConverterConnectionCompoundDynamicAnalysis"],
        "_6527": ["TorqueConverterPumpCompoundDynamicAnalysis"],
        "_6528": ["TorqueConverterTurbineCompoundDynamicAnalysis"],
        "_6529": ["UnbalancedMassCompoundDynamicAnalysis"],
        "_6530": ["VirtualComponentCompoundDynamicAnalysis"],
        "_6531": ["WormGearCompoundDynamicAnalysis"],
        "_6532": ["WormGearMeshCompoundDynamicAnalysis"],
        "_6533": ["WormGearSetCompoundDynamicAnalysis"],
        "_6534": ["ZerolBevelGearCompoundDynamicAnalysis"],
        "_6535": ["ZerolBevelGearMeshCompoundDynamicAnalysis"],
        "_6536": ["ZerolBevelGearSetCompoundDynamicAnalysis"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundDynamicAnalysis",
    "AbstractShaftCompoundDynamicAnalysis",
    "AbstractShaftOrHousingCompoundDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearSetCompoundDynamicAnalysis",
    "AssemblyCompoundDynamicAnalysis",
    "BearingCompoundDynamicAnalysis",
    "BeltConnectionCompoundDynamicAnalysis",
    "BeltDriveCompoundDynamicAnalysis",
    "BevelDifferentialGearCompoundDynamicAnalysis",
    "BevelDifferentialGearMeshCompoundDynamicAnalysis",
    "BevelDifferentialGearSetCompoundDynamicAnalysis",
    "BevelDifferentialPlanetGearCompoundDynamicAnalysis",
    "BevelDifferentialSunGearCompoundDynamicAnalysis",
    "BevelGearCompoundDynamicAnalysis",
    "BevelGearMeshCompoundDynamicAnalysis",
    "BevelGearSetCompoundDynamicAnalysis",
    "BoltCompoundDynamicAnalysis",
    "BoltedJointCompoundDynamicAnalysis",
    "ClutchCompoundDynamicAnalysis",
    "ClutchConnectionCompoundDynamicAnalysis",
    "ClutchHalfCompoundDynamicAnalysis",
    "CoaxialConnectionCompoundDynamicAnalysis",
    "ComponentCompoundDynamicAnalysis",
    "ConceptCouplingCompoundDynamicAnalysis",
    "ConceptCouplingConnectionCompoundDynamicAnalysis",
    "ConceptCouplingHalfCompoundDynamicAnalysis",
    "ConceptGearCompoundDynamicAnalysis",
    "ConceptGearMeshCompoundDynamicAnalysis",
    "ConceptGearSetCompoundDynamicAnalysis",
    "ConicalGearCompoundDynamicAnalysis",
    "ConicalGearMeshCompoundDynamicAnalysis",
    "ConicalGearSetCompoundDynamicAnalysis",
    "ConnectionCompoundDynamicAnalysis",
    "ConnectorCompoundDynamicAnalysis",
    "CouplingCompoundDynamicAnalysis",
    "CouplingConnectionCompoundDynamicAnalysis",
    "CouplingHalfCompoundDynamicAnalysis",
    "CVTBeltConnectionCompoundDynamicAnalysis",
    "CVTCompoundDynamicAnalysis",
    "CVTPulleyCompoundDynamicAnalysis",
    "CycloidalAssemblyCompoundDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis",
    "CycloidalDiscCompoundDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis",
    "CylindricalGearCompoundDynamicAnalysis",
    "CylindricalGearMeshCompoundDynamicAnalysis",
    "CylindricalGearSetCompoundDynamicAnalysis",
    "CylindricalPlanetGearCompoundDynamicAnalysis",
    "DatumCompoundDynamicAnalysis",
    "ExternalCADModelCompoundDynamicAnalysis",
    "FaceGearCompoundDynamicAnalysis",
    "FaceGearMeshCompoundDynamicAnalysis",
    "FaceGearSetCompoundDynamicAnalysis",
    "FEPartCompoundDynamicAnalysis",
    "FlexiblePinAssemblyCompoundDynamicAnalysis",
    "GearCompoundDynamicAnalysis",
    "GearMeshCompoundDynamicAnalysis",
    "GearSetCompoundDynamicAnalysis",
    "GuideDxfModelCompoundDynamicAnalysis",
    "HypoidGearCompoundDynamicAnalysis",
    "HypoidGearMeshCompoundDynamicAnalysis",
    "HypoidGearSetCompoundDynamicAnalysis",
    "InterMountableComponentConnectionCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis",
    "MassDiscCompoundDynamicAnalysis",
    "MeasurementComponentCompoundDynamicAnalysis",
    "MountableComponentCompoundDynamicAnalysis",
    "OilSealCompoundDynamicAnalysis",
    "PartCompoundDynamicAnalysis",
    "PartToPartShearCouplingCompoundDynamicAnalysis",
    "PartToPartShearCouplingConnectionCompoundDynamicAnalysis",
    "PartToPartShearCouplingHalfCompoundDynamicAnalysis",
    "PlanetaryConnectionCompoundDynamicAnalysis",
    "PlanetaryGearSetCompoundDynamicAnalysis",
    "PlanetCarrierCompoundDynamicAnalysis",
    "PointLoadCompoundDynamicAnalysis",
    "PowerLoadCompoundDynamicAnalysis",
    "PulleyCompoundDynamicAnalysis",
    "RingPinsCompoundDynamicAnalysis",
    "RingPinsToDiscConnectionCompoundDynamicAnalysis",
    "RollingRingAssemblyCompoundDynamicAnalysis",
    "RollingRingCompoundDynamicAnalysis",
    "RollingRingConnectionCompoundDynamicAnalysis",
    "RootAssemblyCompoundDynamicAnalysis",
    "ShaftCompoundDynamicAnalysis",
    "ShaftHubConnectionCompoundDynamicAnalysis",
    "ShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "SpecialisedAssemblyCompoundDynamicAnalysis",
    "SpiralBevelGearCompoundDynamicAnalysis",
    "SpiralBevelGearMeshCompoundDynamicAnalysis",
    "SpiralBevelGearSetCompoundDynamicAnalysis",
    "SpringDamperCompoundDynamicAnalysis",
    "SpringDamperConnectionCompoundDynamicAnalysis",
    "SpringDamperHalfCompoundDynamicAnalysis",
    "StraightBevelDiffGearCompoundDynamicAnalysis",
    "StraightBevelDiffGearMeshCompoundDynamicAnalysis",
    "StraightBevelDiffGearSetCompoundDynamicAnalysis",
    "StraightBevelGearCompoundDynamicAnalysis",
    "StraightBevelGearMeshCompoundDynamicAnalysis",
    "StraightBevelGearSetCompoundDynamicAnalysis",
    "StraightBevelPlanetGearCompoundDynamicAnalysis",
    "StraightBevelSunGearCompoundDynamicAnalysis",
    "SynchroniserCompoundDynamicAnalysis",
    "SynchroniserHalfCompoundDynamicAnalysis",
    "SynchroniserPartCompoundDynamicAnalysis",
    "SynchroniserSleeveCompoundDynamicAnalysis",
    "TorqueConverterCompoundDynamicAnalysis",
    "TorqueConverterConnectionCompoundDynamicAnalysis",
    "TorqueConverterPumpCompoundDynamicAnalysis",
    "TorqueConverterTurbineCompoundDynamicAnalysis",
    "UnbalancedMassCompoundDynamicAnalysis",
    "VirtualComponentCompoundDynamicAnalysis",
    "WormGearCompoundDynamicAnalysis",
    "WormGearMeshCompoundDynamicAnalysis",
    "WormGearSetCompoundDynamicAnalysis",
    "ZerolBevelGearCompoundDynamicAnalysis",
    "ZerolBevelGearMeshCompoundDynamicAnalysis",
    "ZerolBevelGearSetCompoundDynamicAnalysis",
)



"""ConicalGearSetLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.gears.load_case import _874
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_SET_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.Gears.LoadCase.Conical", "ConicalGearSetLoadCase"
)

if TYPE_CHECKING:
    from mastapy.gears.load_case.bevel import _893
    from mastapy.gears.analysis import _1226, _1217


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearSetLoadCase",)


Self = TypeVar("Self", bound="ConicalGearSetLoadCase")


class ConicalGearSetLoadCase(_874.GearSetLoadCaseBase):
    """ConicalGearSetLoadCase

    This is a mastapy class.
    """

    TYPE = _CONICAL_GEAR_SET_LOAD_CASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ConicalGearSetLoadCase")

    class _Cast_ConicalGearSetLoadCase:
        """Special nested class for casting ConicalGearSetLoadCase to subclasses."""

        def __init__(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
            parent: "ConicalGearSetLoadCase",
        ):
            self._parent = parent

        @property
        def gear_set_load_case_base(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
        ) -> "_874.GearSetLoadCaseBase":
            return self._parent._cast(_874.GearSetLoadCaseBase)

        @property
        def gear_set_design_analysis(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
        ) -> "_1226.GearSetDesignAnalysis":
            from mastapy.gears.analysis import _1226

            return self._parent._cast(_1226.GearSetDesignAnalysis)

        @property
        def abstract_gear_set_analysis(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
        ) -> "_1217.AbstractGearSetAnalysis":
            from mastapy.gears.analysis import _1217

            return self._parent._cast(_1217.AbstractGearSetAnalysis)

        @property
        def bevel_set_load_case(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
        ) -> "_893.BevelSetLoadCase":
            from mastapy.gears.load_case.bevel import _893

            return self._parent._cast(_893.BevelSetLoadCase)

        @property
        def conical_gear_set_load_case(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase",
        ) -> "ConicalGearSetLoadCase":
            return self._parent

        def __getattr__(
            self: "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ConicalGearSetLoadCase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(self: Self) -> "ConicalGearSetLoadCase._Cast_ConicalGearSetLoadCase":
        return self._Cast_ConicalGearSetLoadCase(self)



"""BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5540
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_PLANET_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = (
    python_net_import(
        "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound",
        "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
    )
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.mbd_analyses import _5392
    from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
        _5545,
        _5533,
        _5561,
        _5587,
        _5606,
        _5554,
        _5608,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",)


Self = TypeVar(
    "Self", bound="BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis"
)


class BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis(
    _5540.BevelDifferentialGearCompoundMultibodyDynamicsAnalysis
):
    """BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _BEVEL_DIFFERENTIAL_PLANET_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf",
        bound="_Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
    )

    class _Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis:
        """Special nested class for casting BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis to subclasses."""

        def __init__(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
            parent: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ):
            self._parent = parent

        @property
        def bevel_differential_gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5540.BevelDifferentialGearCompoundMultibodyDynamicsAnalysis":
            return self._parent._cast(
                _5540.BevelDifferentialGearCompoundMultibodyDynamicsAnalysis
            )

        @property
        def bevel_gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5545.BevelGearCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5545,
            )

            return self._parent._cast(_5545.BevelGearCompoundMultibodyDynamicsAnalysis)

        @property
        def agma_gleason_conical_gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5533.AGMAGleasonConicalGearCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5533,
            )

            return self._parent._cast(
                _5533.AGMAGleasonConicalGearCompoundMultibodyDynamicsAnalysis
            )

        @property
        def conical_gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5561.ConicalGearCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5561,
            )

            return self._parent._cast(
                _5561.ConicalGearCompoundMultibodyDynamicsAnalysis
            )

        @property
        def gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5587.GearCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5587,
            )

            return self._parent._cast(_5587.GearCompoundMultibodyDynamicsAnalysis)

        @property
        def mountable_component_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5606.MountableComponentCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5606,
            )

            return self._parent._cast(
                _5606.MountableComponentCompoundMultibodyDynamicsAnalysis
            )

        @property
        def component_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5554.ComponentCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5554,
            )

            return self._parent._cast(_5554.ComponentCompoundMultibodyDynamicsAnalysis)

        @property
        def part_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_5608.PartCompoundMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses.compound import (
                _5608,
            )

            return self._parent._cast(_5608.PartCompoundMultibodyDynamicsAnalysis)

        @property
        def part_compound_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def bevel_differential_planet_gear_compound_multibody_dynamics_analysis(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
        ) -> "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis":
            return self._parent

        def __getattr__(
            self: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases_ready(
        self: Self,
    ) -> "List[_5392.BevelDifferentialPlanetGearMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.BevelDifferentialPlanetGearMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def component_analysis_cases(
        self: Self,
    ) -> "List[_5392.BevelDifferentialPlanetGearMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.BevelDifferentialPlanetGearMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis":
        return self._Cast_BevelDifferentialPlanetGearCompoundMultibodyDynamicsAnalysis(
            self
        )
